import { a as require_react, o as __toESM, t as require_jsx_runtime } from "../index.js";
//#region app/page.tsx
var import_react = /* @__PURE__ */ __toESM(require_react(), 1);
var import_jsx_runtime = require_jsx_runtime();
var Arrow = () => /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
	"aria-hidden": "true",
	children: "↗"
});
var Chevron = () => /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
	"aria-hidden": "true",
	children: "⌄"
});
var services = [
	{
		code: "01",
		title: "Artificial Intelligence",
		img: "https://images.unsplash.com/photo-1518770660439-4636190af475?auto=format&fit=crop&w=1400&q=85",
		copy: "Intelligent systems that learn, predict and create measurable advantage."
	},
	{
		code: "02",
		title: "Software Engineering",
		img: "https://images.unsplash.com/photo-1531297484001-80022131f5a1?auto=format&fit=crop&w=1400&q=85",
		copy: "Resilient digital products, platforms and enterprise applications."
	},
	{
		code: "03",
		title: "Cybersecurity",
		img: "https://images.unsplash.com/photo-1550751827-4bd374c3f58b?auto=format&fit=crop&w=1400&q=85",
		copy: "Security architecture that protects every layer of your operation."
	},
	{
		code: "04",
		title: "Telecommunications",
		img: "https://images.unsplash.com/photo-1451187580459-43490279c0fa?auto=format&fit=crop&w=1400&q=85",
		copy: "Infrastructure and networks engineered for always-on connection."
	},
	{
		code: "05",
		title: "Data & Analytics",
		img: "https://images.unsplash.com/photo-1523961131990-5ea7c61b2107?auto=format&fit=crop&w=1400&q=85",
		copy: "Clear signals, governed pipelines and decisions backed by evidence."
	},
	{
		code: "06",
		title: "Media & Experience",
		img: "https://images.unsplash.com/photo-1492619375914-88005aa9e8fb?auto=format&fit=crop&w=1400&q=85",
		copy: "Digital experiences and content systems that hold attention."
	},
	{
		code: "07",
		title: "Intelligent Automation",
		img: "https://images.unsplash.com/photo-1504384308090-c894fdcc538d?auto=format&fit=crop&w=1400&q=85",
		copy: "Connected workflows that remove friction and multiply capacity."
	}
];
var cases = [
	{
		stat: "99.99%",
		label: "Platform availability",
		title: "Rebuilding a national-scale digital backbone",
		sector: "Infrastructure",
		img: "https://images.unsplash.com/photo-1558494949-ef010cbdcc31?auto=format&fit=crop&w=1600&q=85"
	},
	{
		stat: "3.4×",
		label: "Faster decisions",
		title: "Turning live operations into a strategic asset",
		sector: "Data intelligence",
		img: "https://images.unsplash.com/photo-1551288049-bebda4e38f71?auto=format&fit=crop&w=1600&q=85"
	},
	{
		stat: "62%",
		label: "Lower handling time",
		title: "Automating service without losing the human touch",
		sector: "AI & automation",
		img: "https://images.unsplash.com/photo-1485827404703-89b55fcc595e?auto=format&fit=crop&w=1600&q=85"
	}
];
function Home() {
	const [menu, setMenu] = (0, import_react.useState)(false);
	const [mega, setMega] = (0, import_react.useState)(false);
	const [theme, setTheme] = (0, import_react.useState)("dark");
	const [modal, setModal] = (0, import_react.useState)(false);
	const [toast, setToast] = (0, import_react.useState)(false);
	const [tab, setTab] = (0, import_react.useState)(0);
	const [slide, setSlide] = (0, import_react.useState)(0);
	const [openFaq, setOpenFaq] = (0, import_react.useState)(0);
	(0, import_react.useEffect)(() => {
		document.documentElement.dataset.theme = theme;
	}, [theme]);
	const notify = () => {
		setToast(true);
		window.setTimeout(() => setToast(false), 3200);
	};
	return /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("main", { children: [
		/* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", {
			className: "skip-link",
			href: "#content",
			children: "Skip to content"
		}),
		/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("header", {
			className: "nav-wrap",
			children: [
				/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("nav", {
					className: "nav container",
					"aria-label": "Main navigation",
					children: [
						/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("a", {
							className: "brand",
							href: "#",
							"aria-label": "NIOSUS home",
							children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
								className: "brand-mark",
								children: "N"
							}), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: "NIOSUS" })]
						}),
						/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
							className: "nav-links",
							children: [
								/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("button", {
									className: "nav-link",
									onClick: () => setMega(!mega),
									"aria-expanded": mega,
									children: ["Capabilities ", /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Chevron, {})]
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", {
									className: "nav-link",
									href: "#work",
									children: "Work"
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", {
									className: "nav-link",
									href: "#about",
									children: "Company"
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", {
									className: "nav-link",
									href: "#insights",
									children: "Insights"
								})
							]
						}),
						/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
							className: "nav-actions",
							children: [
								/* @__PURE__ */ (0, import_jsx_runtime.jsx)("button", {
									className: "icon-button tooltip",
									"data-tip": `Switch to ${theme === "dark" ? "light" : "dark"} theme`,
									"aria-label": "Toggle colour theme",
									onClick: () => setTheme(theme === "dark" ? "light" : "dark"),
									children: theme === "dark" ? "☼" : "◐"
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("button", {
									className: "button button-small",
									onClick: () => setModal(true),
									children: ["Start a project ", /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})]
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("button", {
									className: "menu-toggle",
									"aria-label": "Open menu",
									"aria-expanded": menu,
									onClick: () => setMenu(!menu),
									children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {}), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {})]
								})
							]
						})
					]
				}),
				mega && /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {
					className: "mega-menu",
					children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
						className: "container mega-grid",
						children: [
							/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
								className: "mega-intro",
								children: [
									/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
										className: "eyebrow",
										children: "Capabilities"
									}),
									/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("h3", { children: [
										"Connected expertise.",
										/* @__PURE__ */ (0, import_jsx_runtime.jsx)("br", {}),
										"One clear direction."
									] }),
									/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("a", {
										href: "#capabilities",
										children: ["Explore all capabilities ", /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})]
									})
								]
							}),
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {
								className: "mega-services",
								children: services.slice(0, 6).map((s) => /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("a", {
									href: "#capabilities",
									onClick: () => setMega(false),
									children: [
										/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: s.code }),
										s.title,
										/* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})
									]
								}, s.code))
							}),
							/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
								className: "mega-feature",
								children: [
									/* @__PURE__ */ (0, import_jsx_runtime.jsx)("img", {
										src: services[0].img,
										alt: "Abstract circuitry representing artificial intelligence"
									}),
									/* @__PURE__ */ (0, import_jsx_runtime.jsx)("p", { children: "Featured capability" }),
									/* @__PURE__ */ (0, import_jsx_runtime.jsx)("strong", { children: "Applied AI for the real world" })
								]
							})
						]
					})
				}),
				menu && /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {
					className: "mobile-menu",
					children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
						className: "container",
						children: [
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
								className: "eyebrow",
								children: "Navigate"
							}),
							[
								"Capabilities",
								"Work",
								"Company",
								"Insights"
							].map((item, i) => /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("a", {
								href: i === 0 ? "#capabilities" : i === 1 ? "#work" : i === 2 ? "#about" : "#insights",
								onClick: () => setMenu(false),
								children: [
									/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", { children: ["0", i + 1] }),
									item,
									/* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})
								]
							}, item)),
							/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("button", {
								className: "button",
								onClick: () => {
									setMenu(false);
									setModal(true);
								},
								children: ["Start a project ", /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})]
							})
						]
					})
				})
			]
		}),
		/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("section", {
			className: "hero",
			id: "content",
			children: [
				/* @__PURE__ */ (0, import_jsx_runtime.jsx)("img", {
					className: "hero-media",
					src: "https://images.unsplash.com/photo-1519608487953-e999c86e7455?auto=format&fit=crop&w=2400&q=90",
					alt: "Earth and city lights seen from space"
				}),
				/* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", { className: "hero-overlay" }),
				/* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {
					className: "hero-grid",
					"aria-hidden": "true"
				}),
				/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
					className: "container hero-content",
					children: [
						/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", {
							className: "eyebrow light",
							children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("i", {}), " Technology, engineered for impact"]
						}),
						/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("h1", { children: [
							"Complexity,",
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("br", {}),
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("em", { children: "made powerful." })
						] }),
						/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
							className: "hero-bottom",
							children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("p", { children: "NIOSUS connects strategy, technology and human insight to build systems that move organisations—and society—forward." }), /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("a", {
								className: "circle-link",
								href: "#capabilities",
								"aria-label": "Explore our capabilities",
								children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: "Explore" }), /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})]
							})]
						})
					]
				}),
				/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
					className: "hero-index",
					children: [
						/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: "01" }),
						/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { className: "line" }),
						/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: "07" })
					]
				})
			]
		}),
		/* @__PURE__ */ (0, import_jsx_runtime.jsx)("section", {
			className: "statement section",
			id: "about",
			children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
				className: "container split",
				children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", { children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", {
					className: "eyebrow",
					children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("i", {}), " What we believe"]
				}) }), /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("h2", {
						className: "display",
						children: ["The future doesn’t arrive fully formed. ", /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: "We build it—responsibly, intelligently, together." })]
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("p", {
						className: "lead",
						children: "From the first strategic question to the final line of code, we make advanced technology useful, resilient and unmistakably human."
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("a", {
						className: "text-link",
						href: "#principles",
						children: ["Our point of view ", /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})]
					})
				] })]
			})
		}),
		/* @__PURE__ */ (0, import_jsx_runtime.jsx)("section", {
			className: "capabilities section",
			id: "capabilities",
			children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
				className: "container",
				children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
					className: "section-head",
					children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", {
						className: "eyebrow light",
						children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("i", {}), " What we do"]
					}), /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("h2", { children: [
						"Capability,",
						/* @__PURE__ */ (0, import_jsx_runtime.jsx)("br", {}),
						"without silos."
					] })] }), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("p", { children: "Deep specialists working as one team across the entire technology lifecycle." })]
				}), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {
					className: "service-list",
					children: services.map((s) => /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("article", {
						className: "service-row",
						children: [
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
								className: "service-code",
								children: s.code
							}),
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {
								className: "service-thumb",
								children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)("img", {
									src: s.img,
									alt: "",
									loading: "lazy"
								})
							}),
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("h3", { children: s.title }),
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("p", { children: s.copy }),
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("button", {
								"aria-label": `Explore ${s.title}`,
								children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})
							})
						]
					}, s.code))
				})]
			})
		}),
		/* @__PURE__ */ (0, import_jsx_runtime.jsx)("section", {
			className: "work section",
			id: "work",
			children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
				className: "container",
				children: [
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
						className: "section-head dark-text",
						children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", {
							className: "eyebrow",
							children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("i", {}), " Selected impact"]
						}), /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("h2", { children: [
							"Work that",
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("br", {}),
							"moves the needle."
						] })] }), /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
							className: "slider-controls",
							children: [
								/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", { children: [
									"0",
									slide + 1,
									" / 0",
									cases.length
								] }),
								/* @__PURE__ */ (0, import_jsx_runtime.jsx)("button", {
									onClick: () => setSlide((slide - 1 + cases.length) % cases.length),
									"aria-label": "Previous project",
									children: "←"
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsx)("button", {
									onClick: () => setSlide((slide + 1) % cases.length),
									"aria-label": "Next project",
									children: "→"
								})
							]
						})]
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("article", {
						className: "case-card",
						children: [
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("img", {
								src: cases[slide].img,
								alt: ""
							}),
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", { className: "case-overlay" }),
							/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
								className: "case-top",
								children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: cases[slide].sector }), /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", { children: ["Case study ", /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})] })]
							}),
							/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
								className: "case-copy",
								children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("strong", { children: cases[slide].stat }), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: cases[slide].label })] }), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("h3", { children: cases[slide].title })]
							})
						]
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {
						className: "slider-dots",
						children: cases.map((_, i) => /* @__PURE__ */ (0, import_jsx_runtime.jsx)("button", {
							className: slide === i ? "active" : "",
							onClick: () => setSlide(i),
							"aria-label": `View slide ${i + 1}`
						}, i))
					})
				]
			})
		}),
		/* @__PURE__ */ (0, import_jsx_runtime.jsx)("section", {
			className: "system section",
			id: "principles",
			children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
				className: "container",
				children: [
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
						className: "section-title",
						children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", {
							className: "eyebrow",
							children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("i", {}), " Built into every engagement"]
						}), /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("h2", { children: [
							"One system.",
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("br", {}),
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: "Many ways forward." })
						] })]
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {
						className: "tabs",
						role: "tablist",
						"aria-label": "Our working principles",
						children: [
							"Explore",
							"Engineer",
							"Evolve"
						].map((t, i) => /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("button", {
							role: "tab",
							"aria-selected": tab === i,
							className: tab === i ? "active" : "",
							onClick: () => setTab(i),
							children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", { children: ["0", i + 1] }), t]
						}, t))
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
						className: "tab-panel",
						role: "tabpanel",
						children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
							className: "kicker",
							children: [
								"See the whole system",
								"Build with conviction",
								"Compound the advantage"
							][tab]
						}), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("h3", { children: [
							"We find the signal inside the complexity.",
							"We turn clear thinking into dependable technology.",
							"We keep learning long after launch."
						][tab] })] }), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("p", { children: [
							"Research, data and direct collaboration reveal the real opportunity—not just the obvious brief.",
							"Multidisciplinary teams move from architecture to delivery with quality, security and scale designed in.",
							"Measurement, optimisation and knowledge transfer make every release stronger than the last."
						][tab] })]
					})
				]
			})
		}),
		/* @__PURE__ */ (0, import_jsx_runtime.jsx)("section", {
			className: "component-lab section",
			id: "insights",
			children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
				className: "container",
				children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
					className: "section-title",
					children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", {
						className: "eyebrow",
						children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("i", {}), " Foundation components"]
					}), /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("h2", { children: [
						"Clear by default.",
						/* @__PURE__ */ (0, import_jsx_runtime.jsx)("br", {}),
						/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: "Responsive by design." })
					] })]
				}), /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
					className: "lab-grid",
					children: [
						/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
							className: "lab-card",
							children: [
								/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
									className: "lab-label",
									children: "Inputs & actions"
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("label", { children: ["Email address", /* @__PURE__ */ (0, import_jsx_runtime.jsx)("input", {
									type: "email",
									placeholder: "you@company.com"
								})] }),
								/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
									className: "button-row",
									children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("button", {
										className: "button",
										onClick: notify,
										children: ["Primary action ", /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})]
									}), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("button", {
										className: "button button-ghost",
										onClick: () => setModal(true),
										children: "Open modal"
									})]
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
									className: "state-row",
									children: [
										/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
											className: "badge success",
											children: "● Operational"
										}),
										/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
											className: "badge warning",
											children: "● Attention"
										}),
										/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
											className: "badge error",
											children: "● Error"
										})
									]
								})
							]
						}),
						/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
							className: "lab-card",
							children: [
								/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
									className: "lab-label",
									children: "Loading & progress"
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {
									className: "loading-line",
									children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {})
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
									className: "skeleton",
									children: [
										/* @__PURE__ */ (0, import_jsx_runtime.jsx)("i", {}),
										/* @__PURE__ */ (0, import_jsx_runtime.jsx)("i", {}),
										/* @__PURE__ */ (0, import_jsx_runtime.jsx)("i", {})
									]
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {
									className: "progress",
									children: /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", { style: { width: "72%" } })
								}),
								/* @__PURE__ */ (0, import_jsx_runtime.jsx)("small", { children: "Preparing your secure workspace…" })
							]
						}),
						/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
							className: "lab-card faq",
							children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
								className: "lab-label",
								children: "Accordions"
							}), [
								"How do engagements begin?",
								"Can NIOSUS work with our team?",
								"What regions do you support?"
							].map((q, i) => /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
								className: `faq-item ${openFaq === i ? "open" : ""}`,
								children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("button", {
									onClick: () => setOpenFaq(openFaq === i ? -1 : i),
									"aria-expanded": openFaq === i,
									children: [q, /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: openFaq === i ? "−" : "+" })]
								}), openFaq === i && /* @__PURE__ */ (0, import_jsx_runtime.jsx)("p", { children: [
									"With a focused discovery session that defines the opportunity, outcomes and right team.",
									"Yes. We integrate with internal teams and transfer knowledge throughout delivery.",
									"We work across Africa and globally through distributed, senior specialist teams."
								][i] })]
							}, q))]
						})
					]
				})]
			})
		}),
		/* @__PURE__ */ (0, import_jsx_runtime.jsx)("section", {
			className: "cta",
			children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
				className: "container cta-inner",
				children: [
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", {
						className: "eyebrow light",
						children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("i", {}), " Your next move"]
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("h2", { children: [
						"Have a hard problem?",
						/* @__PURE__ */ (0, import_jsx_runtime.jsx)("br", {}),
						/* @__PURE__ */ (0, import_jsx_runtime.jsx)("em", { children: "Good." })
					] }),
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("p", { children: "Bring us the challenge. We’ll bring the clarity, craft and technical depth to move it forward." }),
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("button", {
						className: "circle-link filled",
						onClick: () => setModal(true),
						children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: "Let’s talk" }), /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})]
					})
				]
			})
		}),
		/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("footer", { children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
			className: "container footer-grid",
			children: [
				/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("a", {
					className: "brand footer-brand",
					href: "#",
					children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
						className: "brand-mark",
						children: "N"
					}), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: "NIOSUS" })]
				}), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("p", { children: "Technology for a more capable world." })] }),
				/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
						className: "footer-label",
						children: "Navigate"
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", {
						href: "#capabilities",
						children: "Capabilities"
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", {
						href: "#work",
						children: "Work"
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", {
						href: "#about",
						children: "Company"
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", {
						href: "#insights",
						children: "Insights"
					})
				] }),
				/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
						className: "footer-label",
						children: "Connect"
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", {
						href: "mailto:hello@niosus.com",
						children: "hello@niosus.com"
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("a", {
						href: "#",
						children: ["LinkedIn ", /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})]
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("a", {
						href: "#",
						children: ["Instagram ", /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})]
					})
				] }),
				/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", {
						className: "footer-label",
						children: "Stay informed"
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("p", { children: "Ideas on technology, design and progress." }),
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
						className: "subscribe",
						children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("input", {
							"aria-label": "Email for newsletter",
							placeholder: "Email address"
						}), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("button", {
							onClick: notify,
							"aria-label": "Subscribe",
							children: "→"
						})]
					})
				] })
			]
		}), /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
			className: "container footer-bottom",
			children: [
				/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: "© 2026 NIOSUS. All rights reserved." }),
				/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", {
					href: "#",
					children: "Privacy"
				}), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("a", {
					href: "#",
					children: "Terms"
				})] }),
				/* @__PURE__ */ (0, import_jsx_runtime.jsx)("button", {
					onClick: () => window.scrollTo({
						top: 0,
						behavior: "smooth"
					}),
					children: "Back to top ↑"
				})
			]
		})] }),
		modal && /* @__PURE__ */ (0, import_jsx_runtime.jsx)("div", {
			className: "modal-backdrop",
			role: "presentation",
			onMouseDown: () => setModal(false),
			children: /* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
				className: "modal",
				role: "dialog",
				"aria-modal": "true",
				"aria-labelledby": "modal-title",
				onMouseDown: (e) => e.stopPropagation(),
				children: [
					/* @__PURE__ */ (0, import_jsx_runtime.jsx)("button", {
						className: "modal-close",
						onClick: () => setModal(false),
						"aria-label": "Close dialog",
						children: "×"
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("span", {
						className: "eyebrow",
						children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("i", {}), " Start a conversation"]
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("h2", {
						id: "modal-title",
						children: [
							"What are you",
							/* @__PURE__ */ (0, import_jsx_runtime.jsx)("br", {}),
							"building next?"
						]
					}),
					/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("form", {
						onSubmit: (e) => {
							e.preventDefault();
							setModal(false);
							notify();
						},
						children: [
							/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("label", { children: ["Your name", /* @__PURE__ */ (0, import_jsx_runtime.jsx)("input", {
								required: true,
								placeholder: "Full name"
							})] }),
							/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("label", { children: ["Work email", /* @__PURE__ */ (0, import_jsx_runtime.jsx)("input", {
								type: "email",
								required: true,
								placeholder: "you@company.com"
							})] }),
							/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("label", { children: ["Tell us about the challenge", /* @__PURE__ */ (0, import_jsx_runtime.jsx)("textarea", {
								required: true,
								placeholder: "A few useful details…",
								rows: 3
							})] }),
							/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("button", {
								className: "button",
								type: "submit",
								children: ["Send enquiry ", /* @__PURE__ */ (0, import_jsx_runtime.jsx)(Arrow, {})]
							})
						]
					})
				]
			})
		}),
		/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", {
			className: `toast ${toast ? "show" : ""}`,
			role: "status",
			children: [
				/* @__PURE__ */ (0, import_jsx_runtime.jsx)("span", { children: "✓" }),
				/* @__PURE__ */ (0, import_jsx_runtime.jsxs)("div", { children: [/* @__PURE__ */ (0, import_jsx_runtime.jsx)("strong", { children: "Received." }), /* @__PURE__ */ (0, import_jsx_runtime.jsx)("small", { children: "We’ll be in touch shortly." })] }),
				/* @__PURE__ */ (0, import_jsx_runtime.jsx)("button", {
					onClick: () => setToast(false),
					children: "×"
				})
			]
		})
	] });
}
//#endregion
export { Home as default };
