export default {
  "bootstrapScriptContent": "import(\"/assets/index-DW7ZLxdR.js\")",
  "clientReferenceDeps": {
    "6efdf509a785": {
      "js": [
        "/assets/page-CYNw4cwn.js",
        "/assets/rolldown-runtime-S-ySWqyJ.js",
        "/assets/framework-DjPHiq1u.js",
        "/assets/index-DW7ZLxdR.js"
      ],
      "css": []
    },
    "8f7ba5393f33": {
      "js": [
        "/assets/index-DW7ZLxdR.js",
        "/assets/rolldown-runtime-S-ySWqyJ.js",
        "/assets/framework-DjPHiq1u.js"
      ],
      "css": []
    },
    "ee6cb3d92c61": {
      "js": [
        "/assets/layout-segment-context-BY_BlvrC.js",
        "/assets/rolldown-runtime-S-ySWqyJ.js",
        "/assets/index-DW7ZLxdR.js",
        "/assets/framework-DjPHiq1u.js"
      ],
      "css": []
    },
    "1e6222746775": {
      "js": [
        "/assets/index-DW7ZLxdR.js",
        "/assets/rolldown-runtime-S-ySWqyJ.js",
        "/assets/framework-DjPHiq1u.js"
      ],
      "css": []
    }
  },
  "serverResources": {
    "app/layout.tsx": {
      "js": [],
      "css": [
        "/assets/index-BZ9LAen8.css"
      ]
    }
  }
}